package com.sun.corba.se.spi.oa;

import com.sun.corba.se.spi.copyobject.ObjectCopierFactory;
import org.omg.CORBA.Policy;
import org.omg.CORBA.Object;
import com.sun.corba.se.spi.protocol.PIHandler;
import com.sun.corba.se.spi.ior.IORFactories;
import com.sun.corba.se.spi.ior.ObjectAdapterId;
import com.sun.corba.se.impl.oa.poa.Policies;
import com.sun.corba.se.spi.ior.ObjectKeyTemplate;
import org.omg.PortableInterceptor.ObjectReferenceFactory;
import org.omg.PortableInterceptor.ObjectReferenceTemplate;
import com.sun.corba.se.spi.ior.IORTemplate;
import com.sun.corba.se.impl.logging.OMGSystemException;
import com.sun.corba.se.impl.logging.POASystemException;
import com.sun.corba.se.spi.orb.ORB;
import org.omg.CORBA.LocalObject;

public abstract class ObjectAdapterBase extends LocalObject implements ObjectAdapter
{
    private ORB orb;
    private final POASystemException _iorWrapper;
    private final POASystemException _invocationWrapper;
    private final POASystemException _lifecycleWrapper;
    private final OMGSystemException _omgInvocationWrapper;
    private final OMGSystemException _omgLifecycleWrapper;
    private IORTemplate iortemp;
    private byte[] adapterId;
    private ObjectReferenceTemplate adapterTemplate;
    private ObjectReferenceFactory currentFactory;
    
    public ObjectAdapterBase(ORB orb) {
        this.orb = orb;
        this._iorWrapper = POASystemException.get(orb, "oa.ior");
        this._lifecycleWrapper = POASystemException.get(orb, "oa.lifecycle");
        this._omgLifecycleWrapper = OMGSystemException.get(orb, "oa.lifecycle");
        this._invocationWrapper = POASystemException.get(orb, "oa.invocation");
        this._omgInvocationWrapper = OMGSystemException.get(orb, "oa.invocation");
    }
    
    public final POASystemException iorWrapper() {
        return this._iorWrapper;
    }
    
    public final POASystemException lifecycleWrapper() {
        return this._lifecycleWrapper;
    }
    
    public final OMGSystemException omgLifecycleWrapper() {
        return this._omgLifecycleWrapper;
    }
    
    public final POASystemException invocationWrapper() {
        return this._invocationWrapper;
    }
    
    public final OMGSystemException omgInvocationWrapper() {
        return this._omgInvocationWrapper;
    }
    
    public final void initializeTemplate(ObjectKeyTemplate objectKeyTemplate, boolean b, Policies policies, String s, String s2, ObjectAdapterId objectAdapterId) {
        this.adapterId = objectKeyTemplate.getAdapterId();
        this.iortemp = IORFactories.makeIORTemplate(objectKeyTemplate);
        this.orb.getCorbaTransportManager().addToIORTemplate(this.iortemp, policies, s, s2, objectAdapterId);
        this.adapterTemplate = IORFactories.makeObjectReferenceTemplate(this.orb, this.iortemp);
        this.currentFactory = this.adapterTemplate;
        if (b) {
            PIHandler piHandler = this.orb.getPIHandler();
            if (piHandler != null) {
                piHandler.objectAdapterCreated(this);
            }
        }
        this.iortemp.makeImmutable();
    }
    
    public final org.omg.CORBA.Object makeObject(String s, byte[] array) {
        return this.currentFactory.make_object(s, array);
    }
    
    public final byte[] getAdapterId() {
        return this.adapterId;
    }
    
    public final ORB getORB() {
        return this.orb;
    }
    
    public abstract Policy getEffectivePolicy(int p0);
    
    public final IORTemplate getIORTemplate() {
        return this.iortemp;
    }
    
    public abstract int getManagerId();
    
    public abstract short getState();
    
    public final ObjectReferenceTemplate getAdapterTemplate() {
        return this.adapterTemplate;
    }
    
    public final ObjectReferenceFactory getCurrentFactory() {
        return this.currentFactory;
    }
    
    public final void setCurrentFactory(ObjectReferenceFactory currentFactory) {
        this.currentFactory = currentFactory;
    }
    
    public abstract org.omg.CORBA.Object getLocalServant(byte[] p0);
    
    public abstract void getInvocationServant(OAInvocationInfo p0);
    
    public abstract void returnServant();
    
    public abstract void enter() throws OADestroyed;
    
    public abstract void exit();
    
    protected abstract ObjectCopierFactory getObjectCopierFactory();
    
    public OAInvocationInfo makeInvocationInfo(byte[] array) {
        OAInvocationInfo oaInvocationInfo = new OAInvocationInfo(this, array);
        oaInvocationInfo.setCopierFactory(this.getObjectCopierFactory());
        return oaInvocationInfo;
    }
    
    public abstract String[] getInterfaces(Object p0, byte[] p1);
}
